==> haskell-protolude-0.3.5-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-protolude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 protolude
version:              0.3.5
visibility:           public
id:                   protolude-0.3.5-5M3GhmgA3m5As7KmxnGIui
key:                  protolude-0.3.5-5M3GhmgA3m5As7KmxnGIui
license:              MIT
copyright:            2016-2022 Stephen Diehl
maintainer:           adamwespiser@gmail.com, stephen.m.diehl@gmail.com
author:               Stephen Diehl
homepage:             https://github.com/sdiehl/protolude
synopsis:             A small prelude.
description:          A sensible set of defaults for writing custom Preludes.
category:             Prelude
abi:                  6a141ac2ff53cca9826cdae93dc6f1f3
exposed:              True
exposed-modules:
    Protolude Protolude.Applicative Protolude.Base Protolude.Bifunctor
    Protolude.Bool Protolude.CallStack Protolude.Conv
    Protolude.ConvertText Protolude.Debug Protolude.Either
    Protolude.Error Protolude.Exceptions Protolude.Functor
    Protolude.List Protolude.Monad Protolude.Panic Protolude.Partial
    Protolude.Safe Protolude.Semiring Protolude.Show Protolude.Unsafe

import-dirs:          /usr/lib/ghc-9.4.8/site-local/protolude-0.3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/protolude-0.3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/protolude-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-protolude
hs-libraries:         HSprotolude-0.3.5-5M3GhmgA3m5As7KmxnGIui
depends:
    array-0.5.4.0 async-2.2.5-I3c3jWJAJDg4b98EnH7ZrW base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0 ghc-prim-0.9.1
    hashable-1.4.4.0-Htybuq5UDQvAvffgJDQoKe mtl-2.2.2 stm-2.5.1.0
    text-2.0.2 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-protolude/html/protolude.haddock
haddock-html:         /usr/share/doc/haskell-protolude/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-protolude-0.3.5-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-protolude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 protolude
version:              0.3.5
visibility:           public
id:                   protolude-0.3.5-5fpr2GHYKjpIN5j5aKBDuf
key:                  protolude-0.3.5-5fpr2GHYKjpIN5j5aKBDuf
license:              MIT
copyright:            2016-2022 Stephen Diehl
maintainer:           adamwespiser@gmail.com, stephen.m.diehl@gmail.com
author:               Stephen Diehl
homepage:             https://github.com/sdiehl/protolude
synopsis:             A small prelude.
description:          A sensible set of defaults for writing custom Preludes.
category:             Prelude
abi:                  a02d92c156fd29d0dda3d60c737c4af3
exposed:              True
exposed-modules:
    Protolude Protolude.Applicative Protolude.Base Protolude.Bifunctor
    Protolude.Bool Protolude.CallStack Protolude.Conv
    Protolude.ConvertText Protolude.Debug Protolude.Either
    Protolude.Error Protolude.Exceptions Protolude.Functor
    Protolude.List Protolude.Monad Protolude.Panic Protolude.Partial
    Protolude.Safe Protolude.Semiring Protolude.Show Protolude.Unsafe

import-dirs:          /usr/lib/ghc-9.4.8/site-local/protolude-0.3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/protolude-0.3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/protolude-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-protolude
hs-libraries:         HSprotolude-0.3.5-5fpr2GHYKjpIN5j5aKBDuf
depends:
    array-0.5.4.0 async-2.2.5-BbhpjNcetBn7sq4yuFYnd1 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0 ghc-prim-0.9.1
    hashable-1.4.4.0-L4Cy5OzOiFo7EDda82f1f2 mtl-2.2.2 stm-2.5.1.0
    text-2.0.2 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-protolude/html/protolude.haddock
haddock-html:         /usr/share/doc/haskell-protolude/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
